@@ -106,6 +106,10 @@ ResourcesRequest::ResourcesRequest(QObject *parent) :
     \endcode
 */
 void ResourcesRequest::list(const QString &resourcePath, const QVariantMap &filters) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
 #if QT_VERSION >= 0x050000    
@@ -135,6 +139,10 @@ void ResourcesRequest::list(const QString &resourcePath, const QVariantMap &filt
     \endcode
 */
 void ResourcesRequest::get(const QString &resourcePath) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     setUrl(u);
@@ -153,6 +161,10 @@ void ResourcesRequest::get(const QString &resourcePath) {
     \endcode
 */
 void ResourcesRequest::insert(const QString &resourcePath) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     setUrl(u);
@@ -176,6 +188,10 @@ void ResourcesRequest::insert(const QString &resourcePath) {
     \endcode
 */
 void ResourcesRequest::insert(const QVariantMap &resource, const QString &resourcePath) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     QString body;
@@ -199,6 +215,10 @@ void ResourcesRequest::insert(const QVariantMap &resource, const QString &resour
     \endcode
 */
 void ResourcesRequest::update(const QString &resourcePath, const QVariantMap &resource) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     QString body;
@@ -219,6 +239,10 @@ void ResourcesRequest::update(const QString &resourcePath, const QVariantMap &re
     \endcode
 */
 void ResourcesRequest::del(const QString &resourcePath) {
+    if (status() == Loading) {
+        return;
+    }
+    
     QUrl u(QString("%1%2%3").arg(API_URL).arg(resourcePath.startsWith("/") ? QString() : QString("/"))
                             .arg(resourcePath));
     setUrl(u);
