@@ -70,7 +70,13 @@ public:
     
         Q_Q(StreamsRequest);
         
-        switch (reply->error()) {
+        const QString response = reply->readAll();
+        const QNetworkReply::NetworkError e = reply->error();
+        const QString es = reply->errorString();
+        reply->deleteLater();
+        reply = 0;
+        
+        switch (e) {
         case QNetworkReply::NoError:
             break;
         case QNetworkReply::OperationCanceledError:
@@ -81,15 +87,15 @@ public:
             return;
         default:
             setStatus(Request::Failed);
-            setError(Request::Error(reply->error()));
-            setErrorString(reply->errorString());
+            setError(Request::Error(e));
+            setErrorString(es);
             emit q->finished();
             return;
         }
         
         bool ok;
-        QVariantMap info = QtJson::Json::parse(QString(reply->readAll()).section("\"h264\":", 1, 1)
-                                                                        .section(",\"hls\":", 0, 0), ok).toMap();
+        const QVariantMap info = QtJson::Json::parse(response.section("\"h264\":", 1, 1)
+                                                             .section(",\"hls\":", 0, 0), ok).toMap();
         
         if (ok) {
             QVariantList list;
@@ -210,7 +216,11 @@ StreamsRequest::StreamsRequest(QObject *parent) :
 /*!
     \brief Requests a list of streams for the video identified by id.
 */
-void StreamsRequest::list(const QString &id) {    
+void StreamsRequest::list(const QString &id) {
+    if (status() == Loading) {
+        return;
+    }
+    
     setUrl(VIDEO_PAGE_URL + "/" + id);
     get(false);
 }
